package com.xkrs.newpro.service.impl;

import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.newpro.dao.QcItemDao;
import com.xkrs.newpro.model.entity.QcItemEntity;
import com.xkrs.newpro.model.qo.QcItemQoInsert;
import com.xkrs.newpro.model.qo.QcItemQoUpdate;
import com.xkrs.newpro.service.QcItemService;
import com.xkrs.newpro.utils.LocalDateUtils;
import org.springframework.context.i18n.LocaleContextHolder;

import javax.annotation.Resource;
import java.util.Locale;
import java.util.Optional;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

public class QcItemServiceImpl implements QcItemService {

    private Locale locale = LocaleContextHolder.getLocale();

    @Resource
    private QcItemDao qcItemDao;

    /**
     * 添加质检项
     */
    @Override
    public String insertQcItem(QcItemQoInsert insertQo) {

        String no = insertQo.getNo();
        String name = insertQo.getName();
        String type = insertQo.getType();

        Optional<QcItemEntity> entityByNo = qcItemDao.findByNo(no);
        if (entityByNo.isPresent()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_EXIT, "该检验项目已存在，请勿重复添加！", locale);
        }

        QcItemEntity entity = new QcItemEntity();
        entity.setCreateTime(LocalDateUtils.getCurrentSecond());
        entity.setUpdateTime("");
        entity.setNo(no);
        entity.setName(name);
        entity.setType(type);
        qcItemDao.save(entity);

        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "添加成功！", locale);
    }

    /**
     * 更新质检项名称
     */
    @Override
    public String updateQcItem(QcItemQoUpdate updateQo) {

        Integer id = updateQo.getId();
        String name = updateQo.getName();

        Optional<QcItemEntity> entityById = qcItemDao.findById(id);
        if (entityById.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "不存在该检验项目，请先添加检验项目！", locale);
        }

        qcItemDao.updateNameById(id, LocalDateUtils.getCurrentSecond(), name);

        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, "修改成功！", locale);
    }
}
